<?php
/**
 * The template for displaying comments.
 *
 * The area of the page that contains both current comments
 * and the comment form.
 *
 * @package 7up-framework
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */

if ( post_password_required() ) {
    return;
}
if(!function_exists('s7upf_comments_list'))
{ 
    function s7upf_comments_list($comment, $args, $depth) {
        $GLOBALS['comment'] = $comment;
        $parent_class = ( empty( $args['has_children'] ) ? '' : 'parent' );
        /* override default avatar size */
        $args['avatar_size'] = 100;
        if ('pingback' == $comment->comment_type || 'trackback' == $comment->comment_type) :
            ?>
        <li class="pingback-comment">
            <span id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>></span>
            <div class="comment-body">
                <?php esc_html_e('Pingback:', 'worldnews'); ?> <?php comment_author_link(); ?> <?php edit_comment_link(esc_html__('Edit', 'worldnews'), '<span class="edit-link"><i class="fa fa-pencil-square-o"></i>', '</span>'); ?>
            </div>
        </li>
    <?php else : ?>
        <li <?php comment_class( $parent_class ); ?>>
            <div id="comment-<?php comment_ID() ?>" class="comment-body">
                <div class="item-comment">
                    <div class="author-avatar">
                        <a href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>"><?php echo get_avatar($comment, $args['avatar_size'])?></a>
                    </div>
                    <div class="comment-info">
                        <h3>
                            <b><?php printf(esc_html__('%s', 'worldnews'), sprintf('%s', get_comment_author_link())); ?></b>
                            <?php esc_html__(' say:', 'worldnews'); ?>
                        </h3>
                        <div class="desc"><?php comment_text();?></div>
                        <span><i class="ion-android-calendar"></i><?php echo get_the_date(get_option('date_format')); ?></span>
                        <span><?php comment_reply_link(array_merge($args, array('add_below' => 'comment', 'depth' => $depth, 'max_depth' => $args['max_depth']))); ?></span>
                    </div>
                </div>
            </div>
        <?php
        endif;
    }
}
?>
<div id="comment" class="comments-area comments">
    <?php // You can start editing here -- including this comment! ?>

    <?php if ( have_comments() ) : ?>
        <div class="post-comment">
            <h2 class="title18">
                <?php
                printf(_nx('One thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'worldnews'), number_format_i18n( get_comments_number()), '<span>'.get_the_title().'</span>');
                ?>
            </h2>
            <ol class="comments-list">
                <?php wp_list_comments( array(
                    'style' => '',
                    'short_ping' => true,
                    'avatar_size' => 100,
                    'max_depth' => '5',
                    'callback' => 's7upf_comments_list',
                        // 'walker' => new s7upf_custom_comment()
                    )
                ); 
                ?>
            </ol>
            <?php if(get_comment_pages_count()>1 && get_option('page_comments')): // are there comments to navigate through ?>
                <nav id="comment-nav-below" class="comment-navigation" role="navigation">
                    <h3 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'worldnews' ); ?></h3>
                    <div class="nav-previous"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'worldnews' ) ); ?></div>
                    <div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'worldnews' ) ); ?></div>
                </nav><!-- #comment-nav-below -->
            <?php endif; // check for comment navigation ?>             
        </div>
    <?php endif; // have_comments() ?>

    <!-- If comments are closed and there are comments, let's leave a little note, shall we? -->
    <?php if (!comments_open() && '0'!=get_comments_number() && post_type_supports(get_post_type(),'comments')): ?>
        <p class="no-comments"><?php esc_html_e('Comments are closed.','worldnews'); ?></p>
    <?php endif; ?>
</div>
<?php
$comment_form = array(
    'title_reply' => esc_html__('Leave a reply', 'worldnews'),
    'fields' => array(
        'author' => '<p>'.esc_html__('Your email address will not be published. Required fields are marked *','worldnews').'</p><input id="author"  name="author" type="text" placeholder="'.esc_html__('Name *','worldnews').'" value="'.esc_attr($commenter['comment_author']).'"  aria-required="true" />',
        'email'  => '<input id="email" name="email" type="text" placeholder="'.esc_html__('Email *','worldnews').'" value="'.esc_attr($commenter['comment_author_email']).'" aria-required="true" />',
        ),
    'logged_in_as' => '
    <p>' .sprintf(wp_kses_post(__( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">'.esc_html__('Log out?','worldnews').'</a>','worldnews' )),admin_url( 'profile.php' ),$user_identity,wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) )) . '<p>',
        'comment_field' => '<textarea class="form-control" rows="5" name="comment" aria-required="true" placeholder="'.esc_html__('Your comment *','worldnews').'"></textarea>',
        'comment_notes_before' => '',
        'comment_notes_after' => '',
        'id_form'              => 'commentform',
        'class_form'           => 'form-leave-comment form-contact',
        'id_submit'            => 'submit',
        'title_reply'          => esc_html__( 'Leave a reply','worldnews' ),
        'title_reply_to'       => esc_html__( 'Leave a reply %s','worldnews' ),
        'cancel_reply_link'    => esc_html__( 'Cancel reply','worldnews' ),
        'label_submit'         => esc_html__( 'Post a comment','worldnews' ),
        'class_submit'         => 'shop-button',
        'title_reply_before' => '<h2 class="title18">',
        'title_reply_after' => '</h2>',
        );
        ?>
        <?php comment_form($comment_form); ?>
        <?php

        class s7upf_custom_comment extends Walker_Comment {

    /** START_LVL 
     * Starts the list before the CHILD elements are added. */
    function start_lvl( &$output, $depth = 0, $args = array() ) {       
        $GLOBALS['comment_depth'] = $depth + 1;

        $output .= '<div class="children">';
    }

    /** END_LVL 
     * Ends the children list of after the elements are added. */
    function end_lvl( &$output, $depth = 0, $args = array() ) {
        $GLOBALS['comment_depth'] = $depth + 1;
        $output .= '</div>';
    }
    function end_el( &$output, $object, $depth = 0, $args = array() ) {
        $output .= '';
    }
}
?>